mlbench_core.controlflow
------------------------

.. autoapimodule:: mlbench_core.controlflow
.. currentmodule:: mlbench_core.controlflow

pytorch
~~~~~~~

.. autoapimodule:: mlbench_core.controlflow.pytorch
.. currentmodule:: mlbench_core.controlflow.pytorch

TrainValidation
+++++++++++++++

.. autoapiclass:: TrainValidation
    :members:

    .. autoapimethod:: __call__

tensorflow
~~~~~~~~~~

.. autoapimodule:: mlbench_core.controlflow.tensorflow
.. currentmodule:: mlbench_core.controlflow.tensorflow


TrainValidation
+++++++++++++++

.. autoapiclass:: TrainValidation
    :members:

    .. autoapimethod:: __call__
